@@ -7,8 +7,11 @@ class ClientModel(ABC):
             example: "Aug 18th, 2022"
         match_list is an optional [list] of strings that are used to match the keys in the dict
             example: ['Fabletics', 'Yitty']
+        match_case is an optional [str] that is used to either exact match or case insensitive match the keys in the dict
+            default: insensitive match
+            example: "exact" or "insensitive"
     '''
-    def __init__(self, _dict=None, author=None, plugin_version=1, heartbeat_required="true", date_created=None, match_list=None):
+    def __init__(self, _dict=None, author=None, plugin_version=1, heartbeat_required="true", date_created=None, match_list=None, match_case="insensitive"):
         self.dict = {}
         self.author = author
         self.__setitem__('author', self.author)
@@ -18,7 +21,12 @@ class ClientModel(ABC):
         self.__setitem__('heartbeat_required', self.heartbeat_required)
         self.date_created = date_created
         self.__setitem__('date_created', self.date_created)
-        if match_list:
+        if match_list and match_case == "exact":
+            for key in _dict.keys():
+                for i in match_list:
+                    if i.lower() == key.lower():
+                        self.__setitem__(key, _dict[key])
+        elif match_list and match_case == "insensitive":
             for key in _dict.keys():
                 for i in match_list:
                     if i.lower() in key.lower():
@@ -81,7 +89,7 @@ class ClientModel(ABC):
     def calculate_total_without_base_values(self):
         ''' calculate the total of all metrics without base values '''
         total = 0
-        for key in self.dict.items():
+        for key, value in self.dict.items():
             if key == 'total':
                 continue
             elif key == 'units':
@@ -94,9 +102,12 @@ class ClientModel(ABC):
                 continue
             elif key == 'date_created':
                 continue
+            elif key.lower().startswith("querytime"):
+                continue
             else:
                 try:
-                    total += int(self.dict[key])
+                    total += int(value)
                 except ValueError:
                     pass
         self.__setitem__('total', total)
+
